
.. _reference:

====================
PyEmir Reference
====================

:Release: |version|

:Date: |today|

.. warning::

   This "Reference" is still a work in progress; some of the material
   is not organized, and several aspects of PyEmir are not yet covered
   sufficient detail.

.. module:: emir

.. toctree::
   :maxdepth: 2

   recipes
   dataproducts
   instrument
   simulation
   simulator

   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
